//
// This file is part of the Marble Virtual Globe.
//
// This program is free software licensed under the GNU LGPL. You can
// find a copy of this license in LICENSE.txt in the top directory of
// the source code.
//
// Copyright 2011      Konrad Enzensberger <e.konrad@mpegcode.com>
//

#include "KmlPolyStyleTagWriter.h"

#include "GeoDataPolyStyle.h"
#include "GeoDataTypes.h"
#include "GeoWriter.h"
#include "KmlElementDictionary.h"

namespace Marble
{

static GeoTagWriterRegistrar s_writerLineStyle(
    GeoTagWriter::QualifiedName( GeoDataTypes::GeoDataPolyStyleType,
                                 kml::kmlTag_nameSpace22 ),
    new KmlPolyStyleTagWriter );

bool KmlPolyStyleTagWriter::write( const GeoNode *node, GeoWriter& writer ) const
{
    const GeoDataPolyStyle *style = static_cast<const GeoDataPolyStyle*>( node );

    writer.writeStartElement( kml::kmlTag_PolyStyle );

    QColor color = style->color();
    QChar fill = QChar( '0' );
    QString colorString = QString( "%1%2%3%4" )
                             .arg( color.alpha(), 2, 16, fill )
                             .arg( color.blue(), 2, 16, fill )
                             .arg( color.green(), 2, 16, fill )
                             .arg( color.red(), 2, 16, fill );
    writer.writeElement( "color", colorString );
//    writer.writeElement( "width", QString::number( style->width() ) );

    writer.writeEndElement();

    return true;
}

}
